pub struct ChartState<CT: CoordTranslate> { /* private fields */ }Expand description
A chart context state - This is the data that is needed to reconstruct the chart context without actually drawing the chart. This is useful when we want to do realtime rendering and want to incrementally update the chart.
For each frame, instead of updating the entire backend, we are able to keep the keep the figure component like axis, labels untouched and make updates only in the plotting drawing area.
Implementations
Sourceimpl<CT: CoordTranslate> ChartState<CT>
impl<CT: CoordTranslate> ChartState<CT>
Sourcepub fn restore<'a, DB: DrawingBackend>(
self,
area: &DrawingArea<DB, Shift>,
) -> ChartContext<'a, DB, CT>
pub fn restore<'a, DB: DrawingBackend>( self, area: &DrawingArea<DB, Shift>, ) -> ChartContext<'a, DB, CT>
Restore the chart context on the given drawing area
area: The given drawing area where we want to restore the chart context- returns The newly created chart context